==> nextcloud-20.0.12.tgz: nextcloud/apps/text/l10n/oc.js <==
OC.L10N.register(
    "text",
    {
    "New text document" : "Novèl fichièr tèxte",
    "Nextcloud Text" : "Nextcloud Text",
    "text document" : "document tèxt",
    "Readme" : "Readme",
    "Text" : "Tèxt",
    "📝 Collaborative document editing" : "📝 Edicion collaborativa de document",
    "Use current version" : "Utilizar la version actuala",
    "Use the saved version" : "Utilizar la version salvada",
    "Reconnect" : "Se reconnectar",
    "The document has been changed outside of the editor. The changes cannot be applied." : "Lo document es estat modificar defòra de l’editor. Se pòdon pas aplicar las modificacions.",
    "Saving …" : "Enregistrament...",
    "Saved" : "Enregistrat",
    "Last saved {lastSaved}" : "Darrièr enregistrament {lastSaved}",
    "Unsaved changes" : "Modificacions pas enregistradas",
    "Enter your name so other users can see who is editing" : "Picatz vòstre nom per que los autres utilizaires vejan qual es a modificar",
    "Edit guest name" : "Modificar lo nom de convidat",
    "Save guest name" : "Enregistrar lo nom de convidat",
    "Insert image" : "Inserir imatge",
    "Insert an image" : "Inserir un imatge",
    "Link file" : "Ligam fichièr",
    "Show author colors" : "Afichar las colors dels utilizaires",
    "Currently active users:" : "Utilizaires actius :",
    "Add notes, lists or links …" : "Apondre nòtas, listas o ligamas…",
    "Edit" : "Modificar",
    "Undo" : "Anullar",
    "Redo" : "Refar",
    "Bold" : "Gras",
    "Italic" : "Italica",
    "Headings" : "Títols",
    "Heading 1" : "Títol 1",
    "Heading 2" : "Títol 2",
    "Heading 3" : "Títol 3",
    "Heading 4" : "Títol 4",
    "Heading 5" : "Títol 5",
    "Heading 6" : "Títol 6",
    "Unordered list" : "Lista pas ordenada",
    "Ordered list" : "Lista ordenada",
    "ToDo list" : "Lista a far",
    "Blockquote" : "Citacion",
    "Code block" : "Còdi",
    "Retry" : "Tornar ensajar",
    "Unpushed changes" : "Modificacions pas enviadas"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-21.0.3.tgz: nextcloud/apps/text/l10n/oc.js <==
OC.L10N.register(
    "text",
    {
    "New text document" : "Novèl fichièr tèxte",
    "Nextcloud Text" : "Nextcloud Text",
    "text document" : "document tèxt",
    "Readme" : "Readme",
    "Text" : "Tèxt",
    "📝 Collaborative document editing" : "📝 Edicion collaborativa de document",
    "Use current version" : "Utilizar la version actuala",
    "Use the saved version" : "Utilizar la version salvada",
    "Reconnect" : "Se reconnectar",
    "The document has been changed outside of the editor. The changes cannot be applied." : "Lo document es estat modificar defòra de l’editor. Se pòdon pas aplicar las modificacions.",
    "Saving …" : "Enregistrament...",
    "Saved" : "Enregistrat",
    "Last saved {lastSaved}" : "Darrièr enregistrament {lastSaved}",
    "Unsaved changes" : "Modificacions pas enregistradas",
    "Enter your name so other users can see who is editing" : "Picatz vòstre nom per que los autres utilizaires vejan qual es a modificar",
    "Edit guest name" : "Modificar lo nom de convidat",
    "Save guest name" : "Enregistrar lo nom de convidat",
    "Insert image" : "Inserir imatge",
    "Insert an image" : "Inserir un imatge",
    "Link file" : "Ligam fichièr",
    "Show author colors" : "Afichar las colors dels utilizaires",
    "Currently active users:" : "Utilizaires actius :",
    "Add notes, lists or links …" : "Apondre nòtas, listas o ligamas…",
    "Edit" : "Modificar",
    "Undo" : "Anullar",
    "Redo" : "Refar",
    "Bold" : "Gras",
    "Italic" : "Italica",
    "Headings" : "Títols",
    "Heading 1" : "Títol 1",
    "Heading 2" : "Títol 2",
    "Heading 3" : "Títol 3",
    "Heading 4" : "Títol 4",
    "Heading 5" : "Títol 5",
    "Heading 6" : "Títol 6",
    "Unordered list" : "Lista pas ordenada",
    "Ordered list" : "Lista ordenada",
    "ToDo list" : "Lista a far",
    "Blockquote" : "Citacion",
    "Code block" : "Còdi",
    "Retry" : "Tornar ensajar",
    "Unpushed changes" : "Modificacions pas enviadas",
    "Add link" : "Apondre un ligam",
    "Show image" : "Afichar imatge",
    "Show file" : "Afichar fichièr",
    "Paragraph" : "Paragraf"
},
"nplurals=2; plural=(n > 1);");
